@@ -4,7 +4,7 @@ use strict;
 use warnings;
 use Exporter::Shiny;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 
 our %EMOJI;
 
@@ -283,11 +283,11 @@ our @EXPORT_OK = keys %EMOJI;
 
 =head1 NAME
 
-Acme::AsciiEmoji - Ascii Emoji's 
+Acme::AsciiEmoji - meta::cpan (ﾉ◕ヮ◕)ﾉ*:・ﾟ✧ index me
 
 =head1 VERSION
 
-Version 0.09
+Version 0.10
 
 =cut
 
